==> kjy-center-api-0.11.49-sources.jar: cn/com/duiba/kjy/api/dto/preInstall/PreInstallBatchDto.java <==
package cn.com.duiba.kjy.api.dto.preInstall;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 *
 * @author kjj mybatis generator
 * 2020-04-13
 */
@Data
public class PreInstallBatchDto implements Serializable {
    private static final long serialVersionUID = 15867560712673799L;

    /**
     *
     *主键ID
     * not null default = null
     */
    private Long id;

    /**
     *
     *预设类型：1:直播预设账号
     * not null default = null
     */
    private Integer preType;

    /**
     *
     *备注
     * max length = 200
     */
    private String remark;

    /**
     *
     *总数量
     * not null default = 0
     */
    private Integer totalCount;

    /**
     *
     *已激活数量
     * not null default = 0
     */
    private Integer activateCount;

    /**
     *
     *二维码链接
     * max length = 256
     */
    private String qrCode;

    /**
     *
     *状态：-1:删除  0：禁用  1:使用中
     * not null default = 1
     */
    private Integer batchStatus;

    /**
     *
     *二维码有效期
     * not null default = null
     */
    private Date vipValidity;

    /**
     *
     *会员周期类型,1:天,2:月 3:年
     * not null default = null
     */
    private Integer vipPeriodType;

    /**
     *
     *会员周期数量
     * not null default = null
     */
    private Integer vipPeriodCount;

    /**
     *
     *用户版本
     * not null default = 2
     */
    private Integer userVersion;

    /**
     * 打款记录ID tb_serial_pay_record.id
     */
    private Long serialId;

    /**
     *
     *创建时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     *
     *修改时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtModified;

    /**
     * 绑定公司ID
     */
    private Long companyId;

    /**
     * 绑定团队的ID
     */
    private Long teamId;

    /**
     * 是否预设手机号
     * @see cn.com.duiba.kjy.api.enums.preInsatll.PrePhoneEnum
     */
    private Integer prePhone;

    /**
     * 客集集公司id
     */
    private Long kjjCompanyId;

    /**
     * 直播id
     */
    private Long liveId;
}

==> kjy-center-api-1.1.26-sources.jar: cn/com/duiba/kjy/api/dto/preInstall/PreInstallBatchDto.java <==
package cn.com.duiba.kjy.api.dto.preInstall;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 *
 * @author kjj mybatis generator
 * 2020-04-13
 */
@Data
public class PreInstallBatchDto implements Serializable {
    private static final long serialVersionUID = 15867560712673799L;

    /**
     *
     *主键ID
     * not null default = null
     */
    private Long id;

    /**
     *
     *预设类型：1:直播预设账号
     * not null default = null
     */
    private Integer preType;

    /**
     *
     *备注
     * max length = 200
     */
    private String remark;

    /**
     *
     *总数量
     * not null default = 0
     */
    private Integer totalCount;

    /**
     *
     *已激活数量
     * not null default = 0
     */
    private Integer activateCount;

    /**
     *
     *二维码链接
     * max length = 256
     */
    private String qrCode;

    /**
     *
     *状态：-1:删除  0：禁用  1:使用中
     * not null default = 1
     */
    private Integer batchStatus;

    /**
     *
     *二维码有效期
     * not null default = null
     */
    private Date vipValidity;

    /**
     *
     *会员周期类型,1:天,2:月 3:年
     * not null default = null
     */
    private Integer vipPeriodType;

    /**
     *
     *会员周期数量
     * not null default = null
     */
    private Integer vipPeriodCount;

    /**
     *
     *用户版本
     * not null default = 2
     */
    private Integer userVersion;

    /**
     * 打款记录ID tb_serial_pay_record.id
     */
    private Long serialId;

    /**
     *
     *创建时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     *
     *修改时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtModified;

    /**
     * 绑定公司ID
     */
    private Long companyId;

    /**
     * 绑定团队的ID
     */
    private Long teamId;

    /**
     * 是否预设手机号
     * @see cn.com.duiba.kjy.api.enums.preInsatll.PrePhoneEnum
     */
    private Integer prePhone;

    /**
     * 客集集公司id
     */
    private Long kjjCompanyId;

    /**
     * 直播id
     */
    private Long liveId;

    /**
     * 合伙人销售id
     */
    private Long partnershipSellerId;

    /**
     * 打卡证明截图
     */
    private String paymentProof;

    /**
     * 商户姓名
     */
    private String businessName;

    /**
     * 机构信息
     */
    private String agencyInfo;

    /**
     * 直播代理人激活方式：1-直接激活（小程序码激活），2-关注公众号激活
     * @see cn.com.duiba.live.conf.service.api.enums.conf.LiveAgentActivateTypeEnum
     */
    private Integer activateType;
}
